@@ -963,7 +963,7 @@ class Zone:
         "SET_LINK_AUDIO_DELAY": "http://{host}/YamahaExtendedControl/v1/{zone}/setLinkAudioDelay?delay={delay}",
         "GET_SCENE_INFO": "http://{host}/YamahaExtendedControl/v1/{zone}/getSceneInfo",
         "SET_SCENE": "http://{host}/YamahaExtendedControl/v1/{zone}/recallScene?num={scene}",
-        "CONTROL_CURSOR": "http://{host}/YamahaExtendedControl/v1/{zone}/controlCursor?cursor={direction}",
+        "CONTROL_CURSOR": "http://{host}/YamahaExtendedControl/v1/{zone}/controlCursor?cursor={command}",
         "CONTROL_MENU": "http://{host}/YamahaExtendedControl/v1/{zone}/controlMenu?menu={menu}",
     }
 
@@ -1431,7 +1431,7 @@ class Zone:
         """
         assert zone in ZONES, "Invalid ZONE value!"
         return Zone.URI["CONTROL_CURSOR"].format(
-            host="{host}", zone=zone, cursor=cursor
+            host="{host}", zone=zone, command=cursor
         )
 
     @staticmethod
